==> haskell-errors-2.3.0-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.3.0
id: errors-2.3.0-DroFkIwWplSIqnbpNJrWIb
key: errors-2.3.0-DroFkIwWplSIqnbpNJrWIb
license: BSD-3-Clause
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
abi: 707bf667e74bc9803bb0a12d05035005
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
import-dirs: /usr/lib/ghc-8.6.5/site-local/errors-2.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/errors-2.3.0
hs-libraries: HSerrors-2.3.0-DroFkIwWplSIqnbpNJrWIb
depends:
    base-4.12.0.0 exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.3.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: errors
version: 2.3.0
id: errors-2.3.0-KiwfkgZwA0gLNGsJTA97Fg
key: errors-2.3.0-KiwfkgZwA0gLNGsJTA97Fg
license: BSD-3-Clause
copyright: 2012, 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".
    .
    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.
category: Control, Error Handling
abi: 442dd3f9550ab8c2555562462373f439
exposed: True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR
import-dirs: /usr/lib/ghc-8.6.5/site-local/errors-2.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/errors-2.3.0
hs-libraries: HSerrors-2.3.0-KiwfkgZwA0gLNGsJTA97Fg
depends:
    base-4.12.0.0 exceptions-0.10.2-D9MYzhqXvqCL8hMQL1PEiN
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji text-1.2.3.1
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html: /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
